close all
% caoutchouc
E = 21e5; nu = 0.45; %nu = 0.28; 
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
L=5;
N=7;
%  
fprintf('------------------------------------------------------\n'); 
fprintf('      3D elasticity BVP on [0,%g]x[0,1]x[0,1]\n',L);
fprintf('         on transform hypercube mesh\n\n');
fprintf('             -div(sigma(u)) = f \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [1]\n');
fprintf('       u_1 = u_2 = 0 on [1],\n');
fprintf('   * Neumann on [2,3,4,5,6]\n');
fprintf('       sigma(u).n = 0 on [2,3,4,5,6]\n');
fprintf(' with f=(0,0,-1)^t, lambda=%g, mu=%g\n',lambda,mu);
fprintf('------------------------------------------------------\n'); 

dim=3;
fprintf('1. Building the mesh using HyperCube function\n');
Th=fc_simesh.HyperCube(dim,[L*N,N,N],'trans',@(q) [L*q(1,:);q(2,:);q(3,:)]);
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
fprintf('2.a Setting 3D elasticity BVP\n');
Hop=Hoperator();
Hop.opStiffElas(dim,lambda,mu);
pde=PDEelt(Hop,{0,0,-1});
bvp=BVP(Th,pde);
bvp.setDirichlet(1,0.,1:3);
fprintf('2.b Solving 3D elasticity BVP\n')
U=bvp.solve('split',true);

fprintf('3. Graphic representations\n');
figure(1)
%Th.plotmesh('legend',false,'PlotOptions',{'Color',0.85*[1,1,1]})
Th.plotmesh('d',2,'legend',true);%,'PlotOptions',{'LineWidth',1.5})
axis image

figure(2)
if fc_tools.comp.isOctave()
  Th.plotmesh('d',1,'Color','b','LineWidth',2)
else
  Th.plotmesh('d',2,'FaceColor','b','FaceAlpha',0.5)
end
hold on
axis image
scale=2000;
idx=Th.find(3); % for hypercube, only 1 elt
sTh=Th.sTh{idx}.copy(); % copy otherwize pointer
sTh.q=sTh.q+scale*[U{1}';U{2}';U{3}'];

sTh.plotmesh('Color','r')
%hold on
%sTh.plotmesh('Color','r')
%axis off, axis image
view(-16,9)

